diff --git a/security/apparmor/audit.c b/security/apparmor/audit.c
index 06ad6a8fcce1890549ffab205aaa1dffd9ac56f2..6933cb2f679b0b816be5151a550a3d668ae1dd65 100644
--- a/security/apparmor/audit.c
+++ b/security/apparmor/audit.c
@@ -113,8 +113,8 @@ static void audit_pre(struct audit_buffer *ab, void *va)
 			audit_log_format(ab, " error=%d", ad->error);
 	}
 
-	if (ad->label) {
-		struct aa_label *label = ad->label;
+	if (ad->subj_label) {
+		struct aa_label *label = ad->subj_label;
 
 		if (label_isprofile(label)) {
 			struct aa_profile *profile = labels_profile(label);
@@ -187,7 +187,7 @@ int aa_audit(int type, struct aa_profile *profile,
 	if (KILL_MODE(profile) && type == AUDIT_APPARMOR_DENIED)
 		type = AUDIT_APPARMOR_KILL;
 
-	ad->label = &profile->label;
+	ad->subj_label = &profile->label;
 
 	aa_audit_msg(type, ad, cb);
 
diff --git a/security/apparmor/file.c b/security/apparmor/file.c
index 01ff612c060e0edcf896d1445ad3ca13b2e0a06e..26d45effdbc74e60434306c4da77413e58dd99fc 100644
--- a/security/apparmor/file.c
+++ b/security/apparmor/file.c
@@ -67,7 +67,7 @@ static void file_audit_cb(struct audit_buffer *ab, void *va)
 
 	if (ad->peer) {
 		audit_log_format(ab, " target=");
-		aa_label_xaudit(ab, labels_ns(ad->label), ad->peer,
+		aa_label_xaudit(ab, labels_ns(ad->subj_label), ad->peer,
 				FLAG_VIEW_SUBNS, GFP_KERNEL);
 	} else if (ad->fs.target) {
 		audit_log_format(ab, " target=");
diff --git a/security/apparmor/include/audit.h b/security/apparmor/include/audit.h
index 85931ec94e916239ff56dcbc988c697f027c77de..096f0a04af87f165035d4859a18803b412eeb0c4 100644
--- a/security/apparmor/include/audit.h
+++ b/security/apparmor/include/audit.h
@@ -109,7 +109,7 @@ struct apparmor_audit_data {
 	int type;
 	u16 class;
 	const char *op;
-	struct aa_label *label;
+	struct aa_label *subj_label;
 	const char *name;
 	const char *info;
 	u32 request;
diff --git a/security/apparmor/ipc.c b/security/apparmor/ipc.c
index f198b8d620a4fb40eb27318e8027e5619a0fe5a5..fd8306399b820c046b94aa74f4e71559cc2e8ee5 100644
--- a/security/apparmor/ipc.c
+++ b/security/apparmor/ipc.c
@@ -71,7 +71,7 @@ static void audit_signal_cb(struct audit_buffer *ab, void *va)
 		audit_log_format(ab, " signal=rtmin+%d",
 				 ad->signal - SIGRT_BASE);
 	audit_log_format(ab, " peer=");
-	aa_label_xaudit(ab, labels_ns(ad->label), ad->peer,
+	aa_label_xaudit(ab, labels_ns(ad->subj_label), ad->peer,
 			FLAGS_NONE, GFP_ATOMIC);
 }
 
diff --git a/security/apparmor/lib.c b/security/apparmor/lib.c
index d6b2750fd72e4510443cc41b368190e474da86e9..c87bccafff446c333fd649aae7525bbfdf7488f5 100644
--- a/security/apparmor/lib.c
+++ b/security/apparmor/lib.c
@@ -297,7 +297,7 @@ static void aa_audit_perms_cb(struct audit_buffer *ab, void *va)
 				   PERMS_NAMES_MASK);
 	}
 	audit_log_format(ab, " peer=");
-	aa_label_xaudit(ab, labels_ns(ad->label), ad->peer,
+	aa_label_xaudit(ab, labels_ns(ad->subj_label), ad->peer,
 				      FLAGS_NONE, GFP_ATOMIC);
 }
 
@@ -357,7 +357,6 @@ int aa_profile_label_perm(struct aa_profile *profile, struct aa_profile *target,
 						    typeof(*rules), list);
 	struct aa_perms perms;
 
-	ad->label = &profile->label;
 	ad->peer = &target->label;
 	ad->request = request;
 
@@ -419,7 +418,7 @@ int aa_check_perms(struct aa_profile *profile, struct aa_perms *perms,
 	}
 
 	if (ad) {
-		ad->label = &profile->label;
+		ad->subj_label = &profile->label;
 		ad->request = request;
 		ad->denied = denied;
 		ad->error = error;
diff --git a/security/apparmor/lsm.c b/security/apparmor/lsm.c
index a8c8b179a16c9b75f22569a0ac308ddb82883ff1..3a9a9902d117ead034b119c1d0b231f8c130eea6 100644
--- a/security/apparmor/lsm.c
+++ b/security/apparmor/lsm.c
@@ -722,11 +722,11 @@ out:
 	return error;
 
 fail:
-	ad.label = begin_current_label_crit_section();
+	ad.subj_label = begin_current_label_crit_section();
 	ad.info = name;
 	ad.error = error = -EINVAL;
 	aa_audit_msg(AUDIT_APPARMOR_DENIED, &ad, NULL);
-	end_current_label_crit_section(ad.label);
+	end_current_label_crit_section(ad.subj_label);
 	goto out;
 }
 
diff --git a/security/apparmor/net.c b/security/apparmor/net.c
index 0c7304cd479c563ba499eb9a21b5d96d9c9662a6..5e50f80e35db07a65e9a88e942b8100117a95724 100644
--- a/security/apparmor/net.c
+++ b/security/apparmor/net.c
@@ -100,7 +100,7 @@ void audit_net_cb(struct audit_buffer *ab, void *va)
 	}
 	if (ad->peer) {
 		audit_log_format(ab, " peer=");
-		aa_label_xaudit(ab, labels_ns(ad->label), ad->peer,
+		aa_label_xaudit(ab, labels_ns(ad->subj_label), ad->peer,
 				FLAGS_NONE, GFP_ATOMIC);
 	}
 }
diff --git a/security/apparmor/resource.c b/security/apparmor/resource.c
index b6b5e1bfe9a26f420c706d65c87d361dfdb2ed40..73ba26c646a5e5c6d53befa85da1f16f9b0101a5 100644
--- a/security/apparmor/resource.c
+++ b/security/apparmor/resource.c
@@ -36,7 +36,7 @@ static void audit_cb(struct audit_buffer *ab, void *va)
 			 rlim_names[ad->rlim.rlim], ad->rlim.max);
 	if (ad->peer) {
 		audit_log_format(ab, " peer=");
-		aa_label_xaudit(ab, labels_ns(ad->label), ad->peer,
+		aa_label_xaudit(ab, labels_ns(ad->subj_label), ad->peer,
 				FLAGS_NONE, GFP_ATOMIC);
 	}
 }
diff --git a/security/apparmor/task.c b/security/apparmor/task.c
index b2a777ed14d88aac9f2529ec9e446be8215f1cd3..552442844ff8e48639d443f85cca98ca177bab51 100644
--- a/security/apparmor/task.c
+++ b/security/apparmor/task.c
@@ -217,7 +217,7 @@ static void audit_ptrace_cb(struct audit_buffer *ab, void *va)
 		}
 	}
 	audit_log_format(ab, " peer=");
-	aa_label_xaudit(ab, labels_ns(ad->label), ad->peer,
+	aa_label_xaudit(ab, labels_ns(ad->subj_label), ad->peer,
 			FLAGS_NONE, GFP_ATOMIC);
 }
 
@@ -263,7 +263,7 @@ static int profile_tracer_perm(struct aa_profile *tracer,
 	if (&tracer->label == tracee)
 		return 0;
 
-	ad->label = &tracer->label;
+	ad->subj_label = &tracer->label;
 	ad->peer = tracee;
 	ad->request = 0;
 	ad->error = aa_capable(&tracer->label, CAP_SYS_PTRACE,
diff --git a/security/apparmor/policy.c b/security/apparmor/policy.c
index 4e26c97f13967b99fc6a896c56434aed46c1b192..d78970d4a85153857aef35b9ba47489fc545bece 100644
--- a/security/apparmor/policy.c
+++ b/security/apparmor/policy.c
@@ -733,7 +733,7 @@ static void audit_cb(struct audit_buffer *ab, void *va)
 
 /**
  * audit_policy - Do auditing of policy changes
  * @label: label to check if it can manage policy
  * @op: policy operation being performed
  * @ns_name: name of namespace being manipulated
  * @name: name of profile being manipulated (NOT NULL)
@@ -742,7 +742,7 @@ static void audit_cb(struct audit_buffer *ab, void *va)
  *
  * Returns: the error to be returned after audit is done
  */
-static int audit_policy(struct aa_label *label, const char *op,
+static int audit_policy(struct aa_label *subj_label, const char *op,
 			const char *ns_name, const char *name,
 			const char *info, int error)
 {
@@ -752,7 +752,7 @@ static int audit_policy(struct aa_label *label, const char *op,
 	ad.name = name;
 	ad.info = info;
 	ad.error = error;
-	ad.label = label;
+	ad.subj_label = subj_label;
 
 	aa_audit_msg(AUDIT_APPARMOR_STATUS, &ad, audit_cb);
 
@@ -733,7 +733,7 @@ static void audit_cb(struct audit_buffer *ab, void *va)
 /**
  * audit_policy - Do auditing of policy changes
- * @label: label to check if it can manage policy
+ * @subj_label: label to check if it can manage policy
  * @op: policy operation being performed
  * @ns_name: name of namespace being manipulated